==> openGion_dev_5.9.15.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF80S.sql <==
/****************************************************************************/
/* GF80 ( DB定義書ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2016/11/04 10:32:20                                            */
/****************************************************************************/
CREATE TABLE GF80 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (    1 )                  NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   varchar           (   50 )                  NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      varchar           (  200 )                                      /*  40 名称         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  50 表示順       */
 , CLM_NAME     varchar           (  120 )                                      /*  60 項目名(漢字) */
 , CLM          varchar           (   30 )                  NOT NULL            /*  70 項目         */
 , CLS_NAME     varchar           (   10 )                  NOT NULL            /*  80 DBｸﾗｽ        */
 , PHY_LENGTH   varchar           (   10 )                                      /*  90 物理桁数     */
 , USE_LENGTH   varchar           (    9 )                                      /* 100 使用桁数     */
 , UK           varchar           (    2 )                                      /* 110 ﾕﾆｰｸｷｰ       */
 , LUK          varchar           (    2 )                                      /* 110 論理ﾕﾆｰｸｷｰ   */
 , IXA          varchar           (    2 )                                      /* 120 ｲﾝﾃﾞｯｸｽA     */
 , IXB          varchar           (    2 )                                      /* 130 ｲﾝﾃﾞｯｸｽB     */
 , IXC          varchar           (    2 )                                      /* 140 ｲﾝﾃﾞｯｸｽC     */
 , IXH          varchar           (    2 )                                      /* 150 ｲﾝﾃﾞｯｸｽH     */
 , IXD          varchar           (    2 )                                      /* 150 ｲﾝﾃﾞｯｸｽD     */
 , IXI          varchar           (    2 )                                      /* 160 ｲﾝﾃﾞｯｸｽI     */
 , IXE          varchar           (    2 )                                      /* 160 ｲﾝﾃﾞｯｸｽE     */
 , IXF          varchar           (    2 )                                      /* 170 ｲﾝﾃﾞｯｸｽF     */
 , IXJ          varchar           (    2 )                                      /* 170 ｲﾝﾃﾞｯｸｽJ     */
 , IXK          varchar           (    2 )                                      /* 180 ｲﾝﾃﾞｯｸｽK     */
 , IXG          varchar           (    2 )                                      /* 180 ｲﾝﾃﾞｯｸｽG     */
 , NOT_NULL     varchar           (    1 )                                      /* 190 ﾉｯﾄﾇﾙ        */
 , C_KEY        varchar           (    1 )                                      /* 200 C_KEY        */
 , F_KEY        varchar           (    1 )                                      /* 210 ﾌｫｰﾘﾝｷｰ      */
 , RENDERER     varchar           (   10 )                                      /* 220 表示種別     */
 , EDITOR       varchar           (   10 )                                      /* 230 編集種別     */
 , DBTYPE       varchar           (   10 )                                      /* 240 文字種別     */
 , DATA_DEFAULT varchar           (  200 )                                      /* 250 初期値       */
 , KBCLM        varchar           (    1 )      DEFAULT 0   NOT NULL            /* 260 ｶﾗﾑ区分      */
 , BIKO         varchar           ( 2000 )                                      /* 270 備考         */
 , CDKH         varchar           (    1 )                                      /* 280 改廃ｺｰﾄﾞ     */
 , COMMENTS     varchar           (  500 )                                      /* 290 ｺﾒﾝﾄ         */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF80S.sql <==
/****************************************************************************/
/* GF80 ( DB定義書ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2017/04/07 09:50:29                                            */
/****************************************************************************/
CREATE TABLE GF80 (
   SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       varchar           (    1 )                  NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , TABLE_NAME   varchar           (   50 )                  NOT NULL            /*  30 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      varchar           (  200 )                                      /*  40 名称         */
 , SEQNO        INTEGER                         DEFAULT 0   NOT NULL            /*  50 表示順       */
 , CLM_NAME     varchar           (  120 )                                      /*  60 項目名(漢字) */
 , CLM          varchar           (   30 )                  NOT NULL            /*  70 項目         */
 , CLS_NAME     varchar           (   10 )                  NOT NULL            /*  80 DBｸﾗｽ        */
 , PHY_LENGTH   varchar           (   10 )                                      /*  90 物理桁数     */
 , USE_LENGTH   varchar           (    9 )                                      /* 100 使用桁数     */
 , UK           varchar           (    2 )                                      /* 110 ﾕﾆｰｸｷｰ       */
 , LUK          varchar           (    2 )                                      /* 110 論理ﾕﾆｰｸｷｰ   */
 , IXA          varchar           (    2 )                                      /* 120 ｲﾝﾃﾞｯｸｽA     */
 , IXB          varchar           (    2 )                                      /* 130 ｲﾝﾃﾞｯｸｽB     */
 , IXC          varchar           (    2 )                                      /* 140 ｲﾝﾃﾞｯｸｽC     */
 , IXH          varchar           (    2 )                                      /* 150 ｲﾝﾃﾞｯｸｽH     */
 , IXD          varchar           (    2 )                                      /* 150 ｲﾝﾃﾞｯｸｽD     */
 , IXI          varchar           (    2 )                                      /* 160 ｲﾝﾃﾞｯｸｽI     */
 , IXE          varchar           (    2 )                                      /* 160 ｲﾝﾃﾞｯｸｽE     */
 , IXF          varchar           (    2 )                                      /* 170 ｲﾝﾃﾞｯｸｽF     */
 , IXJ          varchar           (    2 )                                      /* 170 ｲﾝﾃﾞｯｸｽJ     */
 , IXK          varchar           (    2 )                                      /* 180 ｲﾝﾃﾞｯｸｽK     */
 , IXG          varchar           (    2 )                                      /* 180 ｲﾝﾃﾞｯｸｽG     */
 , NOT_NULL     varchar           (    1 )                                      /* 190 ﾉｯﾄﾇﾙ        */
 , C_KEY        varchar           (    1 )                                      /* 200 C_KEY        */
 , F_KEY        varchar           (    1 )                                      /* 210 ﾌｫｰﾘﾝｷｰ      */
 , RENDERER     varchar           (   10 )                                      /* 220 表示種別     */
 , EDITOR       varchar           (   10 )                                      /* 230 編集種別     */
 , DBTYPE       varchar           (   10 )                                      /* 240 文字種別     */
 , DATA_DEFAULT varchar           (  200 )                                      /* 250 初期値       */
 , KBCLM        varchar           (    1 )      DEFAULT '0' NOT NULL            /* 260 ｶﾗﾑ区分      */
 , BIKO         varchar           ( 2000 )                                      /* 270 備考         */
 , CDKH         varchar           (    1 )                                      /* 280 改廃ｺｰﾄﾞ     */
 , COMMENTS     varchar           (  500 )                                      /* 290 ｺﾒﾝﾄ         */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
